@@ -18,7 +18,7 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0-RELEASE (Compaq Armada M700)
  *
-$Id: properties.c,v 1.19 2002/03/05 02:19:01 kevinv Exp $
+$Id: properties.c,v 1.22 2002/09/19 03:15:24 mmclouglin Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -236,17 +236,18 @@ response_cb (GtkDialog *dialog, gint id, gpointer data)
 }
 
 void
-prop_cb (PanelApplet *applet, gpointer data)
+prop_cb (BonoboUIComponent *uic,
+	 ProgressData      *battstat,
+	 const char        *verb)
 {
-  ProgressData   *battstat = data;
-  GladeXML       *glade_xml;
-  GtkWidget      *layout_table;
-  GtkWidget      *preview_hbox;
-  GtkWidget      *widget;
-  GtkWidget      *batterypixwid, *statuspixwid;
-  guint           percentage;
+  GladeXML  *glade_xml;
+  GtkWidget *layout_table;
+  GtkWidget *preview_hbox;
+  GtkWidget *widget;
+  GtkWidget *batterypixwid, *statuspixwid;
+  guint      percentage;
 
-  apm_readinfo();
+  apm_readinfo (PANEL_APPLET (battstat->applet));
 
 #ifdef __FreeBSD__
   percentage = apminfo.ai_batt_life;
@@ -264,6 +265,8 @@ prop_cb (PanelApplet *applet, gpointer data)
   if (DEBUG) g_print("prop_cb()\n");
 
    if (battstat->prop_win) { 
+     gtk_window_set_screen (GTK_WINDOW (battstat->prop_win),
+			    gtk_widget_get_screen (battstat->applet));
      gtk_window_present (GTK_WINDOW (battstat->prop_win));
      return;
    } 
@@ -273,6 +276,8 @@ prop_cb (PanelApplet *applet, gpointer data)
   
   battstat->prop_win = GTK_DIALOG (glade_xml_get_widget (glade_xml, 
   				   "battstat_properties"));
+  gtk_window_set_screen (GTK_WINDOW (battstat->prop_win),
+			 gtk_widget_get_screen (battstat->applet));
 	
   widget = glade_xml_get_widget (glade_xml, "yellow_spin");
   
