@@ -287,6 +287,31 @@ gkb_sized_render (GKB * gkb)
 
 }
 
+void gkb_update_handlers (GKB *gkb, gboolean disconnect)
+{
+  GdkWindow *root_window;
+
+  root_window = gdk_get_default_root_window ();
+
+  if (disconnect)
+  {
+    if (gkb->button_press_id != -1)
+      g_signal_handler_disconnect (gkb->eventbox, gkb->button_press_id);
+    gkb->button_press_id = -1;
+
+    gdk_window_remove_filter (root_window, event_filter, gkb);
+  }
+  else {
+    gdk_window_add_filter (root_window, event_filter, gkb);
+
+    if (gkb->button_press_id == -1)
+      gkb->button_press_id = g_signal_connect (gkb->eventbox, "button_press_event",
+                                               G_CALLBACK (gkb_button_press_event_cb), gkb);
+
+  }
+
+}
+
 /**
  * gkb_update:
  * @gkb: the GKB. global, so redundant
@@ -303,8 +328,10 @@ gkb_update (GKB * gkb, gboolean set_command)
    * keymap, so when the set_commadn is false, it means that we
    * have changed size. In other words, we can't change size &
    * keymap at the same time */
-  if (set_command)
+  if (set_command) {
+    gkb_update_handlers (gkb, TRUE);
     gkb_system_set_keymap (gkb);
+  }
   else
     gkb_sized_render (gkb);
 
@@ -466,9 +493,12 @@ load_properties (GKB * gkb)
 
   gkb->n = gconf_applet_get_int (PANEL_APPLET(gkb->applet), "num", NULL);
 
-  gkb->key = gkb_load_pref (gkb, "key", "Mod1-Shift_L");
+  gkb->key = gkb_load_pref (gkb, "key", "Alt-Shift_L");
+  gkb->old_key = g_strdup (gkb->key);
 
   convert_string_to_keysym_state (gkb->key, &gkb->keysym, &gkb->state);
+  gkb->old_keysym = gkb->keysym;
+  gkb->old_state = gkb->state;
 
   gkb->is_small = gconf_applet_get_bool (PANEL_APPLET(gkb->applet), "small", NULL);
 #ifdef THIS_IS_UNNECESSARY
@@ -536,8 +566,8 @@ create_gkb_widget (GKB *gkb)
 
   gkb->image = gtk_image_new ();
 
-  g_signal_connect (gkb->eventbox, "button_press_event",
-                    G_CALLBACK (gkb_button_press_event_cb), gkb);
+  gkb->button_press_id = g_signal_connect (gkb->eventbox, "button_press_event",
+                                           G_CALLBACK (gkb_button_press_event_cb), gkb);
 
   gkb->darea_frame = gtk_frame_new (NULL);
   gtk_frame_set_shadow_type (GTK_FRAME (gkb->darea_frame), GTK_SHADOW_OUT);
@@ -660,7 +690,7 @@ global_key_filter (GKB *gkb, GdkXEvent * gdk_xevent, GdkEvent * event)
   XKeyEvent * xkevent = (XKeyEvent *) gdk_xevent;
   gint keysym = XKeycodeToKeysym(GDK_DISPLAY(), xkevent->keycode,0);
 
-  if (keysym == gkb->keysym && xkevent->state == gkb->state)
+ if (strcmp (gkb->key, convert_keysym_state_to_string (XKeycodeToKeysym(GDK_DISPLAY (), xkevent->keycode, 0), xkevent->state)) == 0)
     {
       if (gkb->cur + 1 < gkb->n)
 	gkb->keymap = g_list_nth_data (gkb->maps, ++gkb->cur);
@@ -777,7 +807,10 @@ static void gkb_destroy (GtkWidget * widget, gpointer data) {
 	cmd = g_strdup_printf ("xmodmap %s/.gkb_default.xmm", g_get_home_dir ());
 	system (cmd);
 	g_free (cmd);
-
+	
+	if (gkb->propwindow)
+		gtk_widget_destroy (gkb->propwindow);
+	gkb_update_handlers (gkb, TRUE);
 	g_free(gkb);
 }
 
@@ -815,7 +848,12 @@ gboolean fill_gkb_applet(PanelApplet *applet)
 
   root_window = gdk_get_default_root_window ();
 
+  gkb->keycode = keycode; 
+  /* Incase the key is already grabbed by another application */ 
+  gdk_error_trap_push ();
   gkb_xgrab (keycode, modifiers, root_window);
+  gdk_flush ();
+  gdk_error_trap_pop ();
   gdk_window_add_filter (root_window, event_filter, gkb);
 
   g_signal_connect (G_OBJECT(gkb->applet),
