@@ -132,14 +132,18 @@ struct _GKB
   GtkWidget *darea_frame;
   GtkWidget *image;
   GtkWidget *addwindow;
+  GtkWidget *propwindow;
   GtkTooltips *tooltips;
 
   gint n;
   gint cur;
 
-  gchar *key;
+  gchar *key, *old_key;
   guint keysym, state;
+  gint keycode;
+  guint old_keysym, old_state;
 
+  guint button_press_id;
 };
 
 struct _GkbKeymapWg
@@ -171,7 +175,7 @@ struct _GkbKeymapWg
 /* gkb.c */
 void gkb_update (GKB *gkb, gboolean set_command);
 void alert (const gchar * str);
-void applet_save_session (void);
+void applet_save_session (GKB *gkb);
 
 void add_atk_relation(GtkWidget *obj1, GtkWidget *obj2, AtkRelationType type);  
 void add_atk_namedesc(GtkWidget *widget, const gchar *name, const gchar *desc); 
@@ -186,7 +190,7 @@ void gkb_sized_render (GKB * gkb);
 /* presets.c */
 GList * find_presets (void);
 GList * gkb_preset_load (GList * list);
-GkbKeymap * loadprop (int i);
+GkbKeymap * loadprop (GKB *gkb, int i);
 
 /* prop-list.c */
 GtkWidget * gkb_prop_create_buttons_vbox (GkbPropertyBoxInfo *pbi);
@@ -219,10 +223,14 @@ gboolean convert_string_to_keysym_state(const char *string,
 					guint *state);
 char * convert_keysym_state_to_string(guint keysym,
 					guint state);
-void grab_button_pressed (GtkButton *button, gpointer data);
+void gkb_xgrab   (int        keycode,
+		  int        modifiers,
+		  GdkWindow *root_window);
+void gkb_xungrab (int        keycode,
+		  int        modifiers,
+		  GdkWindow *root_window);
 
-void gkb_xgrab(gint keycode, gint modifiers);
-void gkb_xungrab(gint keycode, gint modifiers);
+void grab_button_pressed (GtkButton *button, gpointer data);
 
 /* gconf.c */
 
@@ -255,7 +263,8 @@ gboolean gconf_applet_get_bool  (PanelApplet *parent,
 
 /* Globals */
 gchar * prefixdir;
-GKB * gkb;
+
+void gkb_update_handlers (GKB *gkb, gboolean disconnect);
 
 G_BEGIN_DECLS
 
