@@ -1,4 +1,4 @@
-/* $Id: weather.c,v 1.55 2002/11/27 20:26:31 kevinv Exp $ */
+/* $Id: weather.c,v 1.55.2.1 2003/03/10 17:41:53 kevinv Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -1488,11 +1488,11 @@ static void wx_start_open (WeatherInfo *info)
     loc = info->location;
     g_return_if_fail(loc != NULL);
 
-    if (loc->radar[0] == '-')
-        return;
+    
     if (info->radar_url)
     	url = g_strdup (info->radar_url);
     else {
+    	 if (loc->radar[0] == '-') return;
 	 url = g_strdup_printf ("http://image.weather.com/web/radar/us_%s_closeradar_medium_usen.jpg", loc->radar);
     }
  
